@@ -1,19 +1,9 @@
 from django.conf.urls.defaults import patterns, url
 from django.contrib.admin.views.decorators import staff_member_required
-from django.utils.translation import ugettext_lazy as _
 
 from oscar.core.application import Application
-from oscar.apps.dashboard.nav import register, Node
 
 from accounts.dashboard import views
-from accounts import names
-
-node = Node(_("Accounts"))
-node.add_child(Node(_(names.UNIT_NAME_PLURAL), 'accounts-list'))
-node.add_child(Node(_('Transfers'), 'transfers-list'))
-node.add_child(Node(_('Deferred income report'), 'report-deferred-income'))
-node.add_child(Node(_('Profile/loss report'), 'report-profit-loss'))
-register(node, 100)
 
 
 class AccountsDashboardApplication(Application):
@@ -26,7 +16,6 @@ class AccountsDashboardApplication(Application):
     account_freeze_view = views.AccountFreezeView
     account_thaw_view = views.AccountThawView
     account_top_up_view = views.AccountTopUpView
-    account_withdraw_view = views.AccountWithdrawView
 
     transfer_list_view = views.TransferListView
     transfer_detail_view = views.TransferDetailView
@@ -51,8 +40,6 @@ class AccountsDashboardApplication(Application):
                 name='accounts-thaw'),
             url(r'^(?P<pk>\d+)/top-up/$', self.account_top_up_view.as_view(),
                 name='accounts-top-up'),
-            url(r'^(?P<pk>\d+)/withdraw/$', self.account_withdraw_view.as_view(),
-                name='accounts-withdraw'),
             url(r'^transfers/$', self.transfer_list_view.as_view(),
                 name='transfers-list'),
             url(r'^transfers/(?P<reference>[A-Z0-9]{32})/$',
